//TODO 在这里添加上你自己的包名

import android.text.TextUtils;
import android.util.Log;

import com.sensorsdata.analytics.android.sdk.SensorsDataAPI;

import org.json.JSONObject;

import java.util.Map;

public class SensorsFocusHelper {
    /**
     * 埋点 App 打开推送消息
     * 事件名：AppOpenNotification
     *
     * @param sfData  推送消息的 extras
     * @param notificationTitle   推送消息的标题
     * @param notificationContent 推送消息的内容
     */
    public static void trackAppOpenNotification(String sfData, String notificationTitle, String notificationContent) {
        try {
            JSONObject jsonObject = null;
            if (!TextUtils.isEmpty(sfData)) {
                jsonObject = new JSONObject(sfData);
            }
            JSONObject properties = new JSONObject();
            // 获取消息标题，并保存在事件属性 msg_title 中
            properties.put("$sf_msg_title", notificationTitle);
            // 获取消息 ID，并保存在事件属性 msg_id 中
            properties.put("$sf_msg_content", notificationContent);
            if (jsonObject != null) {
                properties.put("$sf_msg_id", jsonObject.optString("sf_msg_id"));
                properties.put("$sf_plan_id", jsonObject.optString("sf_plan_id"));
                if(!"null".equals(jsonObject.optString("sf_audience_id"))){
                    properties.put("$sf_audience_id", jsonObject.optString("sf_audience_id"));
                }
                properties.put("$sf_link_url", jsonObject.optString("sf_link_url"));
                properties.put("$sf_plan_strategy_id", jsonObject.optString("sf_plan_strategy_id"));
                properties.put("$sf_plan_type", jsonObject.optString("sf_plan_type"));
                properties.put("$sf_strategy_unit_id", jsonObject.optString("sf_strategy_unit_id"));
                properties.put("$sf_enter_plan_time", jsonObject.optString("sf_enter_plan_time"));
                properties.put("$sf_channel_id", jsonObject.optString("sf_channel_id"));
                properties.put("$sf_channel_category", jsonObject.optString("sf_channel_category"));
                properties.put("$sf_channel_service_name", jsonObject.optString("sf_channel_service_name"));
            }
            // 使用神策分析追踪 "App 消息推送成功" 事件
            SensorsDataAPI.sharedInstance().track("$AppPushClick", properties);
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    /**
     * 处理神策智能运营推送消息。
     *
     * @param notificationExtras 推送消息的 extra
     * @param handler 推送消息处理的回调
     */
    public static void handleSensorsFocusPushMessage(Object notificationExtras,SensorsFocusHandler handler) {
        try {
            String sfData = null;
            if (notificationExtras != null && handler != null) {
                if (notificationExtras instanceof String) {
                    sfData = new JSONObject((String) notificationExtras).optString("sf_data");
                } else if (notificationExtras instanceof Map) {
                    sfData = new JSONObject((Map) notificationExtras).optString("sf_data");
                }
            }
            if (!TextUtils.isEmpty(sfData)) {
                JSONObject sfJson = new JSONObject(sfData);
                if ("OPEN_APP".equals(sfJson.optString("sf_landing_type"))) {
                    handler.handleOpenApp();
                } else if ("LINK".equals(sfJson.optString("sf_landing_type"))) {
                    String url = sfJson.optString("sf_link_url");
                    if (!TextUtils.isEmpty(url)) {
                        handler.handleLink(url);
                    }
                } else if ("CUSTOMIZED".equals(sfJson.optString("sf_landing_type"))) {
                    JSONObject custom = sfJson.optJSONObject("customized");
                    if (custom != null) {
                        handler.handleCustomized(custom);
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 处理神策智能运营推送消息。
     *
     * @param sfData 配置
     * @param handler 推送消息处理的回调
     */
    public static void handleSensorsFocusConfig(String sfData,SensorsFocusHandler handler) {
        try {
            if (!TextUtils.isEmpty(sfData) && handler != null) {
                JSONObject sfJson = new JSONObject(sfData);
                if ("OPEN_APP".equals(sfJson.optString("sf_landing_type"))) {
                    handler.handleOpenApp();
                } else if ("LINK".equals(sfJson.optString("sf_landing_type"))) {
                    String url = sfJson.optString("sf_link_url");
                    if (!TextUtils.isEmpty(url)) {
                        handler.handleLink(url);
                    }
                } else if ("CUSTOMIZED".equals(sfJson.optString("sf_landing_type"))) {
                    JSONObject custom = sfJson.optJSONObject("customized");
                    if (custom != null) {
                        handler.handleCustomized(custom);
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 实现接口以处理 SF 点击推送后的行为
     */
    public interface SensorsFocusHandler{
        /**
         * SF 点击推送后的行为是唤醒应用
         */
        void handleOpenApp();

        /**
         * SF 点击推送后的行为是打开指定链接
         * @param url 链接的值
         */
        void handleLink(String url);

        /**
         * SF 点击推送后的行为是自定义跳转
         * @param customProperties 自定义属性
         */
        void handleCustomized(JSONObject customProperties);
    }
}
